# Generated by Django 3.0.3 on 2021-03-30 02:47

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='IPAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip', models.GenericIPAddressField(unique=True, verbose_name='IP Address')),
                ('init_visit', models.DateTimeField(null=True, verbose_name='Initial visit')),
                ('last_visit', models.DateTimeField(null=True, verbose_name='Most recent visit')),
            ],
        ),
    ]
